# npqtools


Данная Python-библиотека создана для решения популярных NP-сложных задач, таких как:
* Задача коммивояжера
* Задача о рюкзаке
* Задача о поиске Гамильтонова цикла
* Задача о поиске клики 
* Задача о поиске максимальной клики во взвешенном графе

И другие

Решение производится с помощью симуляции квантового отжига в решении QUBO.


